* Redriver Level Transient Simulation

*******************************************************
$ Options, Models and Library
*******************************************************
.option post captab method=gear probe
.option gmindc=1e-13 gshdc=1e-13 runlvl=5

.prot
.inc 'header'

*******************************************************
$The TL model
*******************************************************
.MODEL model1_tl8 W MODELTYPE=RLGC, N=1
+ Lo = 2.55e-07
+ Co = 1.02e-10
+ Ro = 0.585
+ Rs = 2.5e-4
+ Gd = 2.85e-11

.inc 'prbs7.inc'
.unprot


*******************************************************
$ Power, Temperature and Supply
*******************************************************
.temp 90

*******************************************************
$Remove comment for the VDD=1.5V
*******************************************************
.param power=1.5
vavdd1p5	vdd1p5 agnd	power

*******************************************************
$Remove comment for the VDD=3.3V
*******************************************************
$.param power=3.3
$vavdd3p3	vdd3p3 agnd	power

vagnd		agnd 0		0

*******************************************************
$ The equalizer setting
$ EQ 	Input equalization
$  0            8dB
$ VDD/2 	4dB
$ VDD		16dB
*******************************************************
$Remove comment for the trace with 4dB loss at 3Gbps
.param resup=100x resdn=100x

$Remove comment for the trace with 8.dB loss at 3Gbps
$.param resup=100x resdn=1e-3

$Remove comment for the trace with 16dB loss at 3Gbps
$.param resup=1e-3 resdn=100x

requp	vdd3p3 eq 	resup
reqdn	eq agnd		resdn

*******************************************************
$ ros - external Res for the output swing
$ rem - external Res for the pre-emphasis control
$ Please reference to the datasheet for the recommended res values
*******************************************************
.param ros=5.5k rem=2k
ros	os agnd		ros
rem	em agnd		rem

*******************************************************
$ Trace and Input               
*******************************************************
gtlinp  0 inxp1 in 0    '+0.5/50'
gtlinn  0 inxn1 in 0    '-0.5/50'
rtlinp  inxp1 0	50
rtlinn  inxn1 0	50

wlpi N=1 inxp1 0 inxp2 0 fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*2'
wlni N=1 inxn1 0 inxn2 0 fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*2'

cip    inxp2 vinp	4.7n
cin    inxn2 vinn	4.7n

*******************************************************
$ ReDriver PI3EQX6801
*******************************************************
.inc 'netlist.up'

*******************************************************
$ Trace and Output
*******************************************************
cop voutp outxp1 4.7n
con voutn outxn1 4.7n

wlpo N=1 outxp1 0 outp 0 fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*2'
wlno N=1 outxn1 0 outn 0 fgd=8500meg RLGCmodel=model1_tl8 L='25.4mm*2'

rop outp 0 50
ron outn 0 50

*******************************************************
$ Simulation Commands and Probes
*******************************************************
.op
.tran 'per2/50' '20n+200*per2' start=20n sweep rem poi 3 50k 10k 2k

.probe v(in)
.probe redrv_in=v(vinp,vinn)
.probe eqout=v(xredriver.xi0.xi0.xi0.eq_op xredriver.xi0.xi0.xi0.eq_on)
.probe lmtout=v(xredriver.xi0.xi0.lmt_op xredriver.xi0.xi0.lmt_on)
.probe redrv_out=v(voutp voutn)
.probe load=v(outp outn)

.probe tran ax=par('time-int(time/per2)*per2')

.param datarate=6g per2='1/datarate'  dtr='100p' dtf='100p' tdelay=0n amp=600m
.end
